==> apache-juneau-8.1.4-src.zip: juneau-8.1.4/juneau-examples/juneau-examples-rest/src/main/java/org/apache/juneau/examples/rest/command/EchoCommand.java <==
// ***************************************************************************************************************************
// * Licensed to the Apache Software Foundation (ASF) under one or more contributor license agreements.  See the NOTICE file *
// * distributed with this work for additional information regarding copyright ownership.  The ASF licenses this file        *
// * to you under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance            *
// * with the License.  You may obtain a copy of the License at                                                              *
// *                                                                                                                         *
// *  http://www.apache.org/licenses/LICENSE-2.0                                                                             *
// *                                                                                                                         *
// * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an  *
// * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the        *
// * specific language governing permissions and limitations under the License.                                              *
// ***************************************************************************************************************************
package org.apache.juneau.examples.rest.command;

import java.io.*;
import java.util.*;

import org.apache.juneau.microservice.console.*;
import org.apache.juneau.utils.*;

/**
 * Implements an 'echo' console command that simply returns the command arguments as a comma-delimited list.
 *
 * <ul class='seealso'>
 * 	<li class='extlink'>{@source}
 * </ul>
 */
public class EchoCommand extends ConsoleCommand {

	@Override /* ConsoleCommand */
	public String getName() {
		return "echo";
	}

	@Override /* ConsoleCommand */
	public String getInfo() {
		return "Echo command";
	}

	@Override /* ConsoleCommand */
	public String getDescription() {
		return "Simple prints the args of the command as a serialized ObjectMap.";
	}

	@Override /* ConsoleCommand */
	public boolean execute(Scanner in, PrintWriter out, Args args) {
		out.println(args);
		return false;
	}
}

==> apache-juneau-9.0.1-src.zip: juneau-9.0.1/juneau-examples/juneau-examples-rest/src/main/java/org/apache/juneau/examples/rest/command/EchoCommand.java <==
// ***************************************************************************************************************************
// * Licensed to the Apache Software Foundation (ASF) under one or more contributor license agreements.  See the NOTICE file *
// * distributed with this work for additional information regarding copyright ownership.  The ASF licenses this file        *
// * to you under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance            *
// * with the License.  You may obtain a copy of the License at                                                              *
// *                                                                                                                         *
// *  http://www.apache.org/licenses/LICENSE-2.0                                                                             *
// *                                                                                                                         *
// * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an  *
// * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the        *
// * specific language governing permissions and limitations under the License.                                              *
// ***************************************************************************************************************************
package org.apache.juneau.examples.rest.command;

import java.io.*;
import java.util.*;

import org.apache.juneau.collections.*;
import org.apache.juneau.microservice.console.*;

/**
 * Implements an 'echo' console command that simply returns the command arguments as a comma-delimited list.
 *
 * <h5 class='section'>See Also:</h5><ul>
 * </ul>
 */
public class EchoCommand extends ConsoleCommand {

	@Override /* ConsoleCommand */
	public String getName() {
		return "echo";
	}

	@Override /* ConsoleCommand */
	public String getInfo() {
		return "Echo command";
	}

	@Override /* ConsoleCommand */
	public String getDescription() {
		return "Simple prints the args of the command as a serialized JsonMap.";
	}

	@Override /* ConsoleCommand */
	public boolean execute(Scanner in, PrintWriter out, Args args) {
		out.println(args);
		return false;
	}
}
